package dev.fyloz.trial.colorrecipesexplorer.core.services;

import dev.fyloz.trial.colorrecipesexplorer.core.model.Material;
import dev.fyloz.trial.colorrecipesexplorer.core.model.Mix;
import dev.fyloz.trial.colorrecipesexplorer.core.model.MixQuantity;
import dev.fyloz.trial.colorrecipesexplorer.core.services.model.MaterialService;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class InventoryService {

    private MaterialService materialService;

    public InventoryService(MaterialService materialService) {
        this.materialService = materialService;
    }

    public String checkQuantities(Mix mix, Map<Material, Float> quantities) {
        for (Material material : mix.getMixQuantities().stream().map(MixQuantity::getMaterial).collect(Collectors.toList())) {
            if (!material.isMixType()) {
                float quantity = quantities.get(material);

                if (quantity > material.getInventoryQuantity()) {
                    return String.format("%s-%s", mix.getMixID(), material.getMaterialID());
                }
            }
        }

        return null;
    }

    public boolean useMix(Mix mix, Map<Material, Float> quantities) {
        List<Material> materials = mix.getMixQuantities().stream().map(MixQuantity::getMaterial).collect(Collectors.toList());
        for (Material material : materials) {
            if (!material.isMixType()) {
                float quantity = quantities.get(material);

                material.setInventoryQuantity(material.getInventoryQuantity() - quantity);
                if (!materialService.update(material).isPresent()) return false;
            }
        }

        return true;
    }
}
