package dev.fyloz.trial.colorrecipesexplorer.core.services.model;

import dev.fyloz.trial.colorrecipesexplorer.core.model.Material;
import dev.fyloz.trial.colorrecipesexplorer.core.model.MaterialType;
import dev.fyloz.trial.colorrecipesexplorer.core.model.MixType;
import dev.fyloz.trial.colorrecipesexplorer.core.services.GenericService;
import dev.fyloz.trial.colorrecipesexplorer.dao.MixTypeDao;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Optional;

@Service
public class MixTypeService extends GenericService<MixType, MixTypeDao> {

    private MaterialTypeService materialTypeService;

    @Autowired
    public MixTypeService(MixTypeDao mixTypeDao, MaterialTypeService materialTypeService) {
        super(mixTypeDao);
        this.materialTypeService = materialTypeService;
    }

    public Optional<MixType> getByName(String name) {
        return dao.findByTypeName(name);
    }

    public Optional<MixType> getByMaterial(Material material) {
        return dao.findByMaterial(material);
    }

    public Optional<MixType> createByName(String name) {
        Optional<MaterialType> defaultType = materialTypeService.getDefaultMaterialType();
        if (!defaultType.isPresent()) return Optional.empty();

        Optional<MixType> mixTypeByName = getByName(name);
        if (mixTypeByName.isPresent()) {
            return mixTypeByName;
        }

        Material mixTypeMaterial = new Material(name, 0, true, defaultType.get());
        MixType mixType = new MixType(name, mixTypeMaterial);

        return save(mixType);
    }
}
