// Compteurs des produits
let materialNbr = 0;
// Liste des produits
let materials;

let removeText;
let materialSelectorHtml;
let recipeID;

window.addEventListener("load", () => {
    recipeID = document.querySelector("#recipeID").value;

    axios.get(`/mix/selector/${recipeID}/-1`)
        .then(r => {
            materialSelectorHtml = r.data;
            init();
        })
        .catch(e => {
            errorP.innerHTML = "Une erreur est survenue lors de la récupération des produits";
            console.log(e);
        });
});

window.addEventListener("click", e => {
    if (e.target) {
        if (e.target.classList.contains("rowRemover")) {
            document.querySelector(`#row_${e.target.dataset.remove}`).remove();
            return;
        }

        const materialSelector = e.target.parentElement;
        if (materialSelector == null || materialSelector.parentElement == null) {
            hideMaterialList();
            return;
        }
        if (!materialSelector.classList.contains("materialSelector") && !materialSelector.parentElement.classList.contains("materialSelector")) hideMaterialList();
    }
});

document.querySelector("#materials button").addEventListener("click", () => {
    addMaterial(null, null);
});

function addMaterial(materialCode, quantity) {
    let row = addRow();

    let materialSelectionColumn = addColumn(row);
    let quantityInputColumn = addColumn(row);

    let removeButtonColumn = addColumn(row);

    addInput(quantityInputColumn, quantity);
    addSpan(quantityInputColumn);
    addButton(removeButtonColumn);

    materialSelectionColumn.innerHTML = materialSelectorHtml;
    const input = materialSelectionColumn.querySelector("input");
    if (materialCode) {
        const material = materialSelectionColumn.querySelector(`.materialList p[data-materialcode="${materialCode}"]`);

        if (material) {
            input.value = material.dataset.materialcode;
            input.dataset.usepercentages = material.dataset.usepercentages;
        }
    }

    document.querySelector("#materials tbody").appendChild(row);
    materialNbr++;

    checkUnits(input, row);
}

function addInput(parent, quantity) {
    let input = document.createElement("input");

    if (quantity === null) quantity = 0;

    input.type = "number";
    input.name = "quantities";
    input.value = quantity;
    input.step = 0.001;
    input.required = true;

    parent.appendChild(input);
    return input;
}

function addSpan(parent) {
    let span = document.createElement("span");

    span.className = "quantityUnit";
    span.innerText = "mL";

    parent.appendChild(span);
    return span;
}

function addButton(parent) {
    let button = document.createElement("button");

    button.type = "button";
    button.dataset.remove = materialNbr;
    button.className = "rowRemover";
    button.innerText = removeText;

    parent.appendChild(button);
    return button;
}

function addRow() {
    let row = document.createElement("tr");
    row.id = `row_${materialNbr}`;

    return row;
}

function addColumn(parent) {
    let column = document.createElement("td");

    parent.appendChild(column);
    return column;
}

function showMaterialList(input) {
    hideMaterialList();
    input.parentElement.querySelector(".materialSelector .materialList").classList.add("show");
}

function hideMaterialList() {
    const list = document.querySelector(".materialSelector .materialList.show");

    if (list != null) list.classList.remove("show");
}

function selectMaterial(material) {
    const materialName = material.dataset.materialcode;
    const input = material.parentElement.parentElement.querySelector("input");

    input.value = materialName;

    hideMaterialList();
    checkUnits(material, input.parentElement.parentElement.parentElement)
}

function searchMaterial(input) {
    let filter, filterUpper, materials;

    filter = input.value;
    filterUpper = filter.toUpperCase();
    materials = input.parentElement.querySelectorAll(".materialList p");

    materials.forEach(e => {
        if (e.innerText.toUpperCase().indexOf(filterUpper) > -1 ||
            e.dataset.materialtype.toUpperCase().indexOf(filterUpper) > -1) e.style.display = "";
        else e.style.display = "none";
    });

    const found = input.parentElement.querySelector(`.materialList p[data-materialcode="${filter}"]`);
    if (found) input.dataset.usepercentages = found.dataset.usepercentages;

    checkUnits(input, input.parentElement.parentElement.parentElement);
}

function checkUnits(materialSelector, row) {
    const quantityUnits = row.querySelector(".quantityUnit");
    if (materialSelector.dataset.usepercentages === "true") quantityUnits.innerText = "%";
    else quantityUnits.innerText = "mL";
}